@@ -1258,14 +1258,6 @@ bool DominoStyle::objectEventHandler( const TQStyleControlElementData &ceData,
 			case TQEvent::Hide:
 				static_cast<TQWidget*>(obj)->setBackgroundMode(NoBackground);
 				return false;
-			case TQEvent::ApplicationPaletteChange:
-				if(obj->isA("PanelKMenu")) {
-					TQWidget* w = static_cast<TQWidget*>(obj);
-					TQPalette pal = tqApp->palette();
-					pal.setColor(TQColorGroup::ButtonText, alphaBlendColors(_popupMenuColor, pal.active().foreground(), 150));
-					w->setPalette(pal);
-					return true;
-				}
 			default:
 				return false;
 		}
@@ -1676,21 +1668,32 @@ bool DominoStyle::objectEventHandler( const TQStyleControlElementData &ceData,
 			p.setClipping(false);
 			
 			TQColor tabContour2 = tqApp->palette().active().background().dark(150);
+
+			p.save();
 			p.setPen(tabContour2);
 			p.drawLine(x+7,y, w-8,y); // top
 			p.drawLine(x+7,h-1, w-8,h-1); // bottom
 			p.drawLine(x,y+7, x,h-8); // left
 			p.drawLine(w-1,y+7, w-1,h-8); // right
-			
+			p.restore();
+
 			bitBlt(label, x, y, border1, 0, 0, 7, 7);
 			bitBlt(label, w-7, y, border1, 7, 0, 7, 7);
 			bitBlt(label, x, h-7, border1, 0, 7, 7, 7);
 			bitBlt(label, w-7, h-7, border1, 7, 7, 7, 7);
 			
-			TQSimpleRichText* srt = new TQSimpleRichText(label->text(), label->font());
-			srt->setWidth(r.width()-5);
-			srt->draw(&p, r.x()+4, r.y(), r, tqApp->palette().active(),0);
-			delete srt;
+			if(TQStyleSheet::mightBeRichText(label->text()))
+			{
+				TQSimpleRichText* srt = new TQSimpleRichText(label->text(), label->font());
+				srt->setWidth(r.width()-5);
+				srt->draw(&p, r.x()+4, r.y(), r, tqApp->palette().active(), 0);
+				delete srt;
+			}
+			else
+			{
+				r.addCoords(2, 3, 0, 0);
+				p.drawText(r, AlignAuto + AlignTop, label->text());
+			}
 		}
 		return true;
 	}
